@@ -1,15 +1,13 @@
-from __future__ import absolute_import
-
 import collections
 
-from .cache import Cache, _deprecated
+from .cache import Cache
 
 
 class LFUCache(Cache):
     """Least Frequently Used (LFU) cache implementation."""
 
-    def __init__(self, maxsize, missing=_deprecated, getsizeof=None):
-        Cache.__init__(self, maxsize, missing, getsizeof)
+    def __init__(self, maxsize, getsizeof=None):
+        Cache.__init__(self, maxsize, getsizeof)
         self.__counter = collections.Counter()
 
     def __getitem__(self, key, cache_getitem=Cache.__getitem__):
@@ -30,6 +28,6 @@ class LFUCache(Cache):
         try:
             (key, _), = self.__counter.most_common(1)
         except ValueError:
-            raise KeyError('%s is empty' % self.__class__.__name__)
+            raise KeyError('%s is empty' % type(self).__name__) from None
         else:
             return (key, self.pop(key))
